User's Guide
============

This guide is for all users of Zuul.  If you work on a project where
Zuul is used to drive automation (whether that's testing proposed
changes, building artifacts, or deploying builds), this guide will
help you understand the concepts that underlie Zuul, and how to
configure it to meet your needs.


.. toctree::
   :maxdepth: 2

   concepts
   gating
   config
   jobs
   encryption
   badges
   howtos
   vulnerabilities
